@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,39 @@
 
 #include <yaml-cpp/yaml.h>
 
+static bool
+hasValue( const YAML::Node& v )
+{
+    return v.IsDefined() && !v.IsNull();
+}
+
+/** Helper function to grab a QString out of the config, and to warn if not present. */
+static QString
+requireString( const YAML::Node& config, const char* key )
+{
+    auto v = config[ key ];
+    if ( hasValue(v) )
+        return QString::fromStdString( v.as< std::string >() );
+    else
+    {
+        cWarning() << "Required settings.conf key" << key << "is missing.";
+        return QString();
+    }
+}
+
+/** Helper function to grab a bool out of the config, and to warn if not present. */
+static bool
+requireBool( const YAML::Node& config, const char* key, bool d )
+{
+    auto v = config[ key ];
+    if ( hasValue(v) )
+        return v.as< bool >();
+    else
+    {
+        cWarning() << "Required settings.conf key" << key << "is missing.";
+        return d;
+    }
+}
 
 namespace Calamares
 {
@@ -41,7 +74,6 @@ Settings::instance()
     return s_instance;
 }
 
-
 Settings::Settings( const QString& settingsFilePath,
                     bool debugMode,
                     QObject* parent )
@@ -148,20 +180,18 @@ Settings::Settings( const QString& settingsFilePath,
                 }
             }
 
-            m_brandingComponentName = QString::fromStdString( config[ "branding" ]
-                                                              .as< std::string >() );
-            m_promptInstall = config[ "prompt-install" ].as< bool >();
-
-            m_doChroot = config[ "dont-chroot" ] ? !config[ "dont-chroot" ].as< bool >() : true;
+            m_brandingComponentName = requireString( config, "branding" );
+            m_promptInstall = requireBool( config, "prompt-install", false );
+            m_doChroot = !requireBool( config, "dont-chroot", false );
         }
         catch ( YAML::Exception& e )
         {
-            cWarning() << "YAML parser error " << e.what() << "in" << file.fileName();
+            CalamaresUtils::explainYamlException( e, ba, file.fileName() );
         }
     }
     else
     {
-        cWarning() << "Cannot read " << file.fileName();
+        cWarning() << "Cannot read settings file" << file.fileName();
     }
 
     s_instance = this;
@@ -175,7 +205,7 @@ Settings::modulesSearchPaths() const
 }
 
 
-QList<QMap<QString, QString> >
+Settings::InstanceDescriptionList
 Settings::customModuleInstances() const
 {
     return m_customModuleInstances;
