@@ -64,6 +64,11 @@ namespace Logger
         virtual ~CDebug();
     };
 
+    /**
+     * @brief The full path of the log file.
+     */
+    DLLEXPORT QString logFile();
+
     /**
      * @brief Start logging to the log file.
      *
