@@ -1,7 +1,7 @@
 /* === This file is part of Calamares - <https://github.com/calamares> ===
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
- *   Copyright 2017, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2017-2018, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -52,6 +52,8 @@ name:      "foo"      #the module name. must be unique and same as the parent di
 interface: "qtplugin" #can be: qtplugin, python, process, ...
 */
 
+static const char EMERGENCY[] = "emergency";
+
 namespace Calamares
 {
 
@@ -64,13 +66,12 @@ Module::fromDescriptor( const QVariantMap& moduleDescriptor,
                         const QString& configFileName,
                         const QString& moduleDirectory )
 {
-    Module* m = nullptr;
+    std::unique_ptr<Module> m;
 
     QString typeString = moduleDescriptor.value( "type" ).toString();
     QString intfString = moduleDescriptor.value( "interface" ).toString();
 
-    if ( typeString.isEmpty() ||
-         intfString.isEmpty() )
+    if ( typeString.isEmpty() || intfString.isEmpty() )
     {
         cError() << "Bad module descriptor format" << instanceId;
         return nullptr;
@@ -78,15 +79,13 @@ Module::fromDescriptor( const QVariantMap& moduleDescriptor,
     if ( ( typeString == "view" ) || ( typeString == "viewmodule" ) )
     {
         if ( intfString == "qtplugin" )
-        {
-            m = new ViewModule();
-        }
+            m.reset( new ViewModule() );
         else if ( intfString == "pythonqt" )
         {
 #ifdef WITH_PYTHONQT
-            m = new PythonQtViewModule();
+            m.reset( new PythonQtViewModule() );
 #else
-            cError() << "PythonQt modules are not supported in this version of Calamares.";
+            cError() << "PythonQt view modules are not supported in this version of Calamares.";
 #endif
         }
         else
@@ -95,17 +94,13 @@ Module::fromDescriptor( const QVariantMap& moduleDescriptor,
     else if ( typeString == "job" )
     {
         if ( intfString == "qtplugin" )
-        {
-            m = new CppJobModule();
-        }
+            m.reset( new CppJobModule() );
         else if ( intfString == "process" )
-        {
-            m = new ProcessJobModule();
-        }
+            m.reset( new ProcessJobModule() );
         else if ( intfString == "python" )
         {
 #ifdef WITH_PYTHON
-            m = new PythonJobModule();
+            m.reset( new PythonJobModule() );
 #else
             cError() << "Python modules are not supported in this version of Calamares.";
 #endif
@@ -118,9 +113,9 @@ Module::fromDescriptor( const QVariantMap& moduleDescriptor,
 
     if ( !m )
     {
-        cDebug() << "Bad module type (" << typeString
-            << ") or interface string (" << intfString
-            << ") for module " << instanceId;
+        cError() << "Bad module type (" << typeString
+                 << ") or interface string (" << intfString
+                 << ") for module " << instanceId;
         return nullptr;
     }
 
@@ -129,9 +124,7 @@ Module::fromDescriptor( const QVariantMap& moduleDescriptor,
         m->m_directory = moduleDir.absolutePath();
     else
     {
-        cError() << "Bad module directory" << moduleDirectory
-               << "for" << instanceId;
-        delete m;
+        cError() << "Bad module directory" << moduleDirectory << "for" << instanceId;
         return nullptr;
     }
 
@@ -144,11 +137,10 @@ Module::fromDescriptor( const QVariantMap& moduleDescriptor,
     }
     catch ( YAML::Exception& e )
     {
-        cWarning() << "YAML parser error " << e.what();
-        delete m;
+        cError() << "YAML parser error " << e.what();
         return nullptr;
     }
-    return m;
+    return m.release();
 }
 
 
@@ -169,8 +161,7 @@ Module::loadConfigurationFile( const QString& configFileName ) //throws YAML::Ex
         {
             configFilesByPriority.append(
                 QDir( QDir::currentPath() ).absoluteFilePath(
-                    QString( "src/modules/%1/%2" ).arg( m_name )
-                                                  .arg( configFileName ) ) );
+                    QString( "src/modules/%1/%2" ).arg( m_name ).arg( configFileName ) ) );
         }
 
         configFilesByPriority.append(
@@ -201,6 +192,9 @@ Module::loadConfigurationFile( const QString& configFileName ) //throws YAML::Ex
             }
 
             m_configurationMap = CalamaresUtils::yamlMapToVariant( doc ).toMap();
+            m_emergency = m_maybe_emergency
+                          && m_configurationMap.contains( EMERGENCY )
+                          && m_configurationMap[ EMERGENCY ].toBool();
             return;
         }
         else
@@ -226,8 +220,7 @@ Module::instanceId() const
 QString
 Module::instanceKey() const
 {
-    return QString( "%1@%2" ).arg( m_name )
-                             .arg( m_instanceId );
+    return QString( "%1@%2" ).arg( m_name ).arg( m_instanceId );
 }
 
 
@@ -277,13 +270,6 @@ Module::interfaceString() const
 }
 
 
-bool
-Module::isLoaded() const
-{
-    return m_loaded;
-}
-
-
 QVariantMap
 Module::configurationMap()
 {
@@ -300,6 +286,9 @@ void
 Module::initFrom( const QVariantMap& moduleDescriptor )
 {
     m_name = moduleDescriptor.value( "name" ).toString();
+
+    if ( moduleDescriptor.contains( EMERGENCY ) )
+        m_maybe_emergency = moduleDescriptor[ EMERGENCY ].toBool();
 }
 
 } //ns
