@@ -23,7 +23,8 @@
 #include <QDir>
 
 
-namespace Calamares {
+namespace Calamares
+{
 
 
 Module::Type
@@ -46,9 +47,7 @@ PythonJobModule::loadSelf()
     if ( m_loaded )
         return;
 
-    m_job = Calamares::job_ptr( new PythonJob( m_scriptFileName,
-                                               m_workingPath,
-                                               m_configurationMap ) );
+    m_job = Calamares::job_ptr( new PythonJob( m_scriptFileName, m_workingPath, m_configurationMap ) );
     m_loaded = true;
 }
 
@@ -68,9 +67,7 @@ PythonJobModule::initFrom( const QVariantMap& moduleDescriptor )
     m_workingPath = directory.absolutePath();
 
     if ( !moduleDescriptor.value( "script" ).toString().isEmpty() )
-    {
         m_scriptFileName = moduleDescriptor.value( "script" ).toString();
-    }
 }
 
 
